| Title: | 'Text Analyzer Shiny' |
|---|---|
| Description: | Interactive shiny application for working with textmining and text analytics. Various visualizations are provided. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-06-01 07:43:35 UTC |
| Source: | https://github.com/cran/TAShiny |
TAShiny() loads interactive user interface built using R shiny.
TAShiny()TAShiny()
Start TAShiny
The interactive user interface is to provide an easy way for people who are learning Text Mining and Analytics. Includes example data for testing out a few example analysis.
Nothing
## Not run: library(shiny) TAShiny() ## End(Not run)## Not run: library(shiny) TAShiny() ## End(Not run)