Welcome to ClientVPS Mirrors

Help for package TAShiny
Type: Package
Title: 'Text Analyzer Shiny'
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: Interactive shiny application for working with textmining and text analytics. Various visualizations are provided.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,igraph,tm,SnowballC,dplyr,wordcloud2
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2018-11-17 10:28:27 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2018-11-27 17:30:03 UTC

Launch TAShiny Interface

Description

TAShiny() loads interactive user interface built using R shiny.

Usage

TAShiny()

Details

Start TAShiny

The interactive user interface is to provide an easy way for people who are learning Text Mining and Analytics. Includes example data for testing out a few example analysis.

Value

Nothing

Examples

## Not run: 
library(shiny)
TAShiny()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.